# Description

- countries_codes_and_coordinates.csv : Countries with their (ISO 3166-1) Alpha-2 code, Alpha-3 code, UN M49, average latitude and longitude coordinates
Source: https://gist.github.com/tadast/8827699


